package com.monkeycoder.monkeynes.hardware;

import com.monkeycoder.monkeynes.gui.*;

/**
 * The interface all controller types must implement to be compatible with MonkeyNES.
 * <br><br> 
 * Originally part of the MonkeyNES project.
 *
 * @author David Stephens
 */
public interface NesController
{ 
  public static final int TYPE_NONE   = 0;
  public static final int TYPE_JOYPAD = 1;
    
  /**
   * Returns the type of this controller.
   * @return The type number of this controller.
   */   
  public int getType();
  
  /**
   * Returns the name of this type of controller.
   * @return The name of this type of controller.
   */
  public String getTypeName();

  /**
   * Sets the value of a specific button.
   * @param inButton The button whose value is being set.
   * @param inValue The value being set.
   */
  public void setButtonValue( int inButton, int inValue );

  /**
   * Resets the strobe on this controller.
   */ 
  public void resetStrobe();
  
  /**
   * Clears the strobe on this controller.
   */ 
  public void clearStrobe();
  
  /**
   * Gets the value of the next button.
   * @return The value of the next button.
   */ 
  public int getNextButtonValue();
}