package com.monkeycoder.monkeynes.hardware.mapper;

import com.monkeycoder.monkeynes.base.*;
import com.monkeycoder.monkeynes.hardware.*;

/**
 * This factory creates MemoryMappers by number.
 * <br><br> 
 * Originally part of the MonkeyNES project.
 *
 * @author David Stephens
 */
public class MemoryMapperFactory
{
  private NesMainMemory  mainMem = null;
  private NesVideoMemory vidMem  = null;
  
  /**
   * Creates a new MemoryMapperFactory.
   * @param inMainMem Main memory bank that will be used to create new mappers.
   * @param inVidMem Video memory bank that will be used to create new mappers.
   */  
  public MemoryMapperFactory( NesMainMemory inMainMem, NesVideoMemory inVidMem )
  {
    mainMem = inMainMem;
    vidMem  = inVidMem;
  }

  /**
   * Creates a new MemoryMapper.
   * @param inRom ROM accessed by this mapper.
   * @return A new mapper based on the ROM that was passed in.
   */    
  public MemoryMapper getMapper( NesRom inRom )
  {
    switch( inRom.getInesRomHeader().getMapperNumber() )
    {
      case 0:
        return new MemoryMapperZero( mainMem, vidMem, inRom );
      default:
        DebugLog.log( "Unsupported Mapper [" + inRom.getInesRomHeader().getMapperNumber() + "]" );
        return null;  
    }    
  }
}